@@ -186,11 +186,11 @@ var CountdownTimer = new function() {
         if (self.breaks.indexOf(self.repeat) !== -1) {
             self.seconds = self.break_duration;
             self.is_break = true;
-            self.updateBreakStatus(true, self.BIG_BREAK, false);
+            self.updateBreakStatus(true, BIG_BREAK, false);
         } else if (self.mini_breaks.indexOf(self.repeat) !== -1) {
             self.seconds = self.mini_break_duration;
             self.is_break = true;
-            self.updateBreakStatus(true, self.MINI_BREAK, false);
+            self.updateBreakStatus(true, MINI_BREAK, false);
         }
 
         self.updateSeconds(self.seconds, self.seconds_passed, self.until_break);
